from pymorphy3 import MorphAnalyzer

__version__ = '0.1.0'
analyzer = MorphAnalyzer()


def pluralize(number: int, word: str, fallback_forms=None) -> str:
    """Преобразование существительного начальной формы в существительное множественного числа"""
    parsed_word = analyzer.parse(word)[0]

    # Если слово не найдено и заданы fallback-формы, используем их
    if fallback_forms and (parsed_word.tag.POS is None or "UNKN" in parsed_word.tag):
        if number % 10 == 1 and number % 100 != 11:
            return f"{number} {fallback_forms[0]}"
        elif 2 <= number % 10 <= 4 and not (11 <= number % 100 <= 14):
            return f"{number} {fallback_forms[1]}"
        else:
            return f"{number} {fallback_forms[2]}"

    form = parsed_word.make_agree_with_number(number).word
    return f"{number} {form}"



from setuptools import setup, find_packages


setup(
    name='rusgram',
    version='0.1.0',
    packages=find_packages(),
    install_requires=['pymorphy3>=2.0.6'],
    author="Маг Ильяс DOMA (MagIlyasDOMA)",
    author_email='magilyas.doma.09@list.ru',
    url='https://github.com/MagIlyasDOMA/rusgram',
    license='MIT',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3.12',
        'Programming Language :: Python :: 3.13',
        'Programming Language :: Python :: 3.14',
        'Programming Language :: Python :: 3 :: Only',
    ],
    python_requires='>=3.6',
)
